Crate oxid_roblox
source ·Expand description
oxid_roblox is a Roblox web API wrapper written in Rust. It aims to provide an interface to get and modify data from Roblox's web API.
Getting Started
Authentication can be done by setting the .ROBLOSECURITY cookie through oxid_roblox::set_roblosecurity:
oxid_roblox::set_roblosecurity("cookie");
// with dotenv
use dotenv::dotenv;
use std::env;
dotenv().ok();
oxid_roblox::set_roblosecurity(&env::var("COOKIE").unwrap());If a method that requires authentication is called without setting the .ROBLOSECURITY cookie first, the program will panic.
All structs representing the Roblox API models should not be initialised by the user. Instead, they are all built through methods in modules and other structs.
Models can be found in the oxid_roblox::models module:

And methods for getting the corresponding model can be found by searching for the model in the “In Names” category:

Documentation
You can access the documentation at https://docs.rs/oxid_roblox.
Modules
- Structs representing a model with only an ID
- Traits that provide shared methods for structs